// Specific definitions for TPF  -*- C++ -*-

// Copyright (C) 2004-2019 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// Under Section 7 of GPL version 3, you are granted additional
// permissions described in the GCC Runtime Library Exception, version
// 3.1, as published by the Free Software Foundation.

// You should have received a copy of the GNU General Public License and
// a copy of the GCC Runtime Library Exception along with this program;
// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
// <http://www.gnu.org/licenses/>.

/** @file bits/os_defines.h
 *  This is an internal header file, included by other library headers.
 *  Do not attempt to use it directly. @headername{iosfwd}
 */

#ifndef _GLIBCXX_OS_DEFINES
#define _GLIBCXX_OS_DEFINES 1

// System-specific #define, typedefs, corrections, etc, go here.  This
// file will come before all others.

// TPF is a big endian OS, let it be known here.
#define _BIG_ENDIAN 1

// This keeps isanum, et al from being propagated as macros.
#define __NO_CTYPE 1

// We must not see the optimized string functions GNU libc defines.
#define __NO_STRING_INLINES

// TPF has its pthread routines in CTHD, which every program links to,
// so there is no need for week-ness for that.
#define _GLIBCXX_GTHREAD_USE_WEAK 0

// TPF's use of eh_globals.cc results in an excessive number of unnecessary
// COWs for the static __eh_globals_init object.
#define _GLIBCXX_AVOID_GLOBAL_INIT_COW 1

// TPF needs to check for divide by zero despite supporting IEEE 754.
#define _GLIBCXX_CHECK_DIVIDE_BY_ZERO 1

// TPF needs to set up thread-common pointers to the standard I/O streams.
#define _GLIBCXX_USE_SYSTEM_IO_IMPL 1

// TPF needs to issue a system error for uncaught exceptions.
#define _GLIBCXX_USE_SYSTEM_ABORT_IMPL 1

// TPF needs to compile cp-demangle.c with -fexec-charset=ISO8859-1 for
// exception handling purposes, but the rest of the system with the
// IBM-1047 charset. As a result, calls to __cxa_demangle outside of
// cp-demangle.c require encoding conversion before/after demangling.
#define _GLIBCXX_REQUIRE_DEMANGLE_ICONV 1
#define __DEFAULT_CHARSET "IBM-1047"
#define __DEMANGLE_CHARSET "ISO8859-1"
#define __DEFAULT_CHARSET_BAD_ALLOC "St9bad_alloc"
#define __DEMANGLE_CHARSET_BAD_ALLOC				     \
  "\x53\x74\x39\x62\x61\x64\x5f\x61\x6c\x6c\x6f\x63"

// TPF can start with multithreading not active and become a threaded
// environment on the fly.
#define _GLIBCXX_GTHREAD_ALLOW_NON_ACTIVE_START 1

#endif
