// -*- C++ -*- Translate strings.
// Copyright (C) 2019 Free Software Foundation, Inc.
//
// This file is part of GCC.
//
// GCC is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 3, or (at your option)
// any later version.
//
// GCC is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// Under Section 7 of GPL version 3, you are granted additional
// permissions described in the GCC Runtime Library Exception, version
// 3.1, as published by the Free Software Foundation.

// You should have received a copy of the GNU General Public License and
// a copy of the GCC Runtime Library Exception along with this program;
// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
// <http://www.gnu.org/licenses/>.

#include <bits/c++config.h>
#if _GLIBCXX_HOSTED
#include <cstdlib>
#include <cstring>
#endif
#include <iconv.h>
#include "unwind-cxx.h"

#if _GLIBCXX_HOSTED
using std::free;
using std::malloc;
using std::memcpy;
using std::strlen;
#else
// In a freestanding environment, these functions may not be available
// -- but for now, we assume that they are.
extern "C" void free(void *);
extern "C" void *malloc(std::size_t);
extern "C" void *memcpy(void *, const void *, std::size_t);
extern "C" std::size_t strlen(const char *);
#endif

using namespace __cxxabiv1;

extern "C" char *
__cxxabiv1::__cxa_translate(const char *src_string,
			    const char *src_charset, const char *dest_charset,
			    int *status) _GLIBCXX_NOTHROW
{
  std::size_t length, src_left, dest_left, rc;
  char *orig_string, *dest_string, *dest_end;
  iconv_t cd;

  if (!src_string)
    {
      if (status != NULL)
	*status = 0;
      return NULL;
    }

  length = src_left = dest_left = strlen(src_string);
  orig_string = const_cast<char *>(src_string);
  dest_string = (char *)malloc(length+1);
  if (!dest_string)
    {
      if (status != NULL)
	*status = -1;
      return NULL;
    }

  cd = iconv_open(dest_charset, src_charset);
  if (cd == (iconv_t)-1)
    {
      if (status != NULL)
	*status = -2;
      return (char *)memcpy(dest_string, src_string, length+1);
    }

  dest_end = dest_string;
  rc = iconv(cd, &orig_string, &src_left, &dest_end, &dest_left);
  if (rc == (std::size_t)-1)
    {
      if (status != NULL)
	*status = -3;
      memcpy(dest_string, src_string, length);
    }
  *dest_end = '\0';
  iconv_close(cd);

  if (status != NULL)
    *status = 0;
  return dest_string;
}

