// Verbose terminate_handler -*- C++ -*-

// Copyright (C) 2001-2019 Free Software Foundation, Inc.
//
// This file is part of the GNU ISO C++ Library.  This library is free
// software; you can redistribute it and/or modify it under the
// terms of the GNU General Public License as published by the
// Free Software Foundation; either version 3, or (at your option)
// any later version.

// This library is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.

// Under Section 7 of GPL version 3, you are granted additional
// permissions described in the GCC Runtime Library Exception, version
// 3.1, as published by the Free Software Foundation.

// You should have received a copy of the GNU General Public License and
// a copy of the GCC Runtime Library Exception along with this program;
// see the files COPYING3 and COPYING.RUNTIME respectively.  If not, see
// <http://www.gnu.org/licenses/>.

#include <bits/c++config.h>

#if _GLIBCXX_HOSTED
#include <cstdlib>
#include <exception>
#include <bits/exception_defines.h>
#include <cxxabi.h>
#include <cstdio>
#include <cstring>

#if _GLIBCXX_USE_SYSTEM_ABORT_IMPL
#include <sys/cppabort.h>
#define abort __system_abort
#endif

using namespace std;
using namespace abi;

namespace __gnu_cxx
{
_GLIBCXX_BEGIN_NAMESPACE_VERSION

  // A replacement for the standard terminate_handler which prints
  // more information about the terminating exception (if any) on
  // stderr.
  void __verbose_terminate_handler()
  {
    static bool terminating;
    if (terminating)
      {
	fputs("terminate called recursively\n", stderr);
	abort ();
      }
    terminating = true;

    // Make sure there was an exception; terminate is also called for an
    // attempt to rethrow when there is no suitable exception.
    type_info *t = __cxa_current_exception_type();
    if (t)
      {
	// Note that "t->name()" is the mangled name.
	{
	  int status = -1;
	  char *dem = 0;
	  
#if ! _GLIBCXX_REQUIRE_DEMANGLE_ICONV
	  dem = __cxa_demangle(t->name(), 0, 0, &status);
#else
	  // Explicitly check for std::bad_alloc as __cxa_translate will
	  // likely fail to acquire necessary space for iconv conversion.
	  if (strcmp(t->name(), __DEFAULT_CHARSET_BAD_ALLOC) == 0
	      || strcmp(t->name(), __DEMANGLE_CHARSET_BAD_ALLOC) == 0)
	    status = -4;
	  else
	    {
	      bool convert = ! __cxa_is_demangle_charset(t->name());
	      char *mangled;
	      if (convert)
		mangled = __cxa_translate(t->name(), __DEFAULT_CHARSET,
					  __DEMANGLE_CHARSET, &status);
	      else
		mangled = const_cast<char *>(t->name());
	      char *demangled = __cxa_demangle(mangled, 0, 0, &status);
	      if (convert)
		free(mangled);
	      dem = __cxa_translate(demangled, __DEMANGLE_CHARSET,
				    __DEFAULT_CHARSET, &status);
	      free(demangled);
	    }
#endif

	  fputs("terminate called after throwing an instance of '", stderr);
	  if (status == 0)
	    fputs(dem, stderr);
	  else if (status == -4)
	    fputs("std::bad_alloc", stderr);
	  else
	    fputs(t->name(), stderr);
	  fputs("'\n", stderr);
	  fflush(stderr);

	  if (status == 0)
	    free(dem);
	}

	// If the exception is derived from std::exception, we can
	// give more information.
	__try { __throw_exception_again; }
#if __cpp_exceptions
	__catch(const exception& exc)
	  {
	    char const *w = exc.what();
	    fputs("  what():  ", stderr);
	    fputs(w, stderr);
	    fputs("\n", stderr);
	    fflush(stderr);
          }
#endif
	__catch(...) { }
      }
    else
      fputs("terminate called without an active exception\n", stderr);
    
    abort();
  }

_GLIBCXX_END_NAMESPACE_VERSION
} // namespace

#endif
