/* Copyright (C) 1996, 1997, 1998, 1999, 2000 Free Software Foundation, Inc.
   This file is part of the GNU C Library.
   Written by Ulrich Drepper, <drepper@cygnus.com>.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#if !defined(__SYSC__) || !defined(_WEIGHT_H)
#define _WEIGHT_H 1

/* Find index of weight.  */
#ifndef __SYSC__
auto inline int32_t
__attribute ((always_inline))
findidx (const unsigned char **cpp) /* C64PJ - fix for 4.0 GCC */
#else
static
int32_t
FINDIDX(const unsigned char **cpp,
               const int32_t *table,
               const unsigned char *extra,
               const int32_t *indirect)
#endif
{
  int_fast32_t i = table[*(*cpp)++];
  const unsigned char *cp;
  const unsigned char *usrc;

  if (i >= 0)
    /* This is an index into the weight table.  Cool.  */
    return i;

  /* Oh well, more than one sequence starting with this byte.
     Search for the correct one.  */
  cp = &extra[-i];

  usrc = *cpp;
  while (1)
    {
      size_t nhere;

      /* The first thing is the index.  */
      i = *((const int32_t *) cp);
      cp += sizeof (int32_t);

      /* Next is the length of the byte sequence.  These are always
	 short byte sequences so there is no reason to call any
	 function (even if they are inlined).  */
      nhere = *cp++;

      if (i >= 0)
	{
	  /* It is a single character.  If it matches we found our
	     index.  Note that at the end of each list there is an
	     entry of length zero which represents the single byte
	     sequence.  The first (and here only) byte was tested
	     already.  */
	  size_t cnt;

	  for (cnt = 0; cnt < nhere; ++cnt)
	    if (cp[cnt] != usrc[cnt])
	      break;

	  if (cnt == nhere)
	    {
	      /* Found it.  */
	      *cpp += nhere;
	      return i;
	    }

	  /* Up to the next entry.  */
	  cp += nhere;
	  if ((1 + nhere) % __alignof__ (int32_t) != 0)
	    cp += __alignof__ (int32_t) - (1 + nhere) % __alignof__ (int32_t);
	}
      else
	{
	  /* This is a range of characters.  First decide whether the
	     current byte sequence lies in the range.  */
	  size_t cnt;
	  size_t offset = 0;

	  for (cnt = 0; cnt < nhere; ++cnt)
	    if (cp[cnt] != usrc[cnt])
	      break;

	  if (cnt != nhere)
	    {
	      if (cp[cnt] > usrc[cnt])
		{
		  /* Cannot be in this range.  */
		  cp += 2 * nhere;
		  if ((1 + 2 * nhere) % __alignof__ (int32_t) != 0)
		    cp += (__alignof__ (int32_t)
			   - (1 + 2 * nhere) % __alignof__ (int32_t));
		  continue;
		}

	      /* Test against the end of the range.  */
	      for (cnt = 0; cnt < nhere; ++cnt)
		if (cp[nhere + cnt] != usrc[cnt])
		  break;

	      if (cnt != nhere && cp[nhere + cnt] < usrc[cnt])
		{
		  /* Cannot be in this range.  */
		  cp += 2 * nhere;
		  if ((1 + 2 * nhere) % __alignof__ (int32_t) != 0)
		    cp += (__alignof__ (int32_t)
			   - (1 + 2 * nhere) % __alignof__ (int32_t));
		  continue;
		}

	      /* This range matches the next characters.  Now find
		 the offset in the indirect table.  */
	      for (cnt = 0; cp[cnt] == usrc[cnt]; ++cnt);

	      do
		{
		  offset <<= 8;
		  offset += usrc[cnt] - cp[cnt];
		}
	      while (++cnt < nhere);
	    }

	  *cpp += nhere;
	  return indirect[-i + offset];
	}
    }

  /* NOTREACHED */
  return 0x43219876;
}

#ifdef _TPF_SOURCE                                                              //C64CF
/* This function is used by the collate routines to normalize IBM EBCDIC */
/* strings that contain shift-out and shift-in characers.                */
/* It does this by taking each multi-byte character and bracketing it in */
/* it's own set of shift-out and shift-in characters.  This is so that   */
/* these characters are unique and can be found in the collation tables. */

#ifdef __SYSC__
static
#else
auto inline size_t                                                              //C64CF
__attribute ((always_inline))  /* C64PJ - GCC 4.0 fix */
#endif
normalize_mb_string(const char *src, unsigned char *dst,                        //C64CF
                    unsigned char mb_in, unsigned char mb_out,                  //C64CF
                    int mb_len)                                                 //C64CF
{                                                                               //C64CF
   size_t len = 0;                                                              //C64CF
   short state = 0;                                                             //C64CF
   int mb_len2 = mb_len - 2;                                                    //C64CF

   while (*src != '\0') {                                                       //C64CF
      if (state == 0) {                                                         //C64CF
         /* single-byte state */
         if (*src == mb_out) {                                                  //C64CF
            /* shift to multibyte mode and move to next character */
            state = 1;                                                          //C64CF
            src++;                                                              //C64CF
         } else {                                                               //C64CF
            /* copy single byte and move to next character */
            *dst = *src;                                                        //C64CF
            dst++;                                                              //C64CF
            src++;                                                              //C64CF
            len++;                                                              //C64CF
         }                                                                      //C64CF

      } else {                                                                  //C64CF
         /* multi-byte state */
         if (*src == mb_in) {                                                   //C64CF
            /* shift to single byte mode and move to next character */
            state = 0;                                                          //C64CF
            src++;                                                              //C64CF
         } else {                                                               //C64CF
            /* Set shift out character */
            *dst = mb_out;                                                      //C64CF
            dst++;                                                              //C64CF

            /* Copy the multi-byte characters and move the pointers */
            memcpy(dst, src, mb_len2);                                          //C64CF
            dst += mb_len2;                                                     //C64CF
            src += mb_len2;                                                     //C64CF

            /* Set shift in character and increment length */
            *dst = mb_in;                                                       //C64CF
            dst++;                                                              //C64CF
            len += mb_len;                                                      //C64CF
         }                                                                      //C64CF
      }                                                                         //C64CF
   }                                                                            //C64CF

   /* Null-terminate the destination string */
   *dst = '\0';                                                                 //C64CF

   return len;                                                                  //C64CF
}                                                                               //C64CF

#ifdef __SYSC__
     #define findidx(cpp, table, extra, indirect) FINDIDX(cpp, table, extra, indirect)
#endif
#endif                                                                          //C64CF

#endif  /* _WEIGHT_H */
