/* Copyright (C) 2004 Free Software Foundation, Inc.
   This file is part of the GNU C Library.

   The GNU C Library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
   License as published by the Free Software Foundation; either
   version 2.1 of the License, or (at your option) any later version.

   The GNU C Library is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
   Lesser General Public License for more details.

   You should have received a copy of the GNU Lesser General Public
   License along with the GNU C Library; if not, write to the Free
   Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA
   02111-1307 USA.  */

#ifndef _SYS_STAT_H
# error "Never include <bits/stat.h> directly; use <sys/stat.h> instead."
#endif

/**********************************************************************/
/*                                                                    */
/* Note: For TPF, the stat and stat64 structures are identical and    */
/* must be kept that way. They are both defined for the sake of Glibc.*/
/*                                                                    */
/**********************************************************************/
struct stat {
    /* Members required by POSIX.1 (and reserved time members)           */
    __ino_t         st_ino;             /* File serial number.           */
    __nlink_t       st_nlink;           /* Link count.                   */
    __dev_t         st_dev;             /* Device.                       */
    __mode_t        st_mode;            /* File mode.                    */
    __uid_t         st_uid;             /* User ID of the file's owner.  */
    __gid_t         st_gid;             /* Group ID of the file's group. */
    __off_t         st_size;            /* Size of file, in bytes.       */

    /* st_blksize is provided for BSD compatibility                      */
    __blksize_t     st_blksize;         /* Optimal block size for I/O.   */
                                        /* Conventially set to 1 for TPF */

    /* Time stamps                                                       */
    struct timespec st_atimespec;       /* Time of last access.          */
    struct timespec st_mtimespec;       /* Time of last modification.    */
    struct timespec st_ctimespec;       /* Time of last status change.   */

    /* st_blkcnt is provided for BSD compatibility                       */
    __blkcnt_t      st_blocks;          /* Nr. 512-byte blocks allocated.*/

    /* TPF-specific members                                              */
    int             st_igen;            /* I-node generation.            */
    rdev_t          st_rdev;            /* Major and minor numbers.      */
    int             st_inode_version;   /* I-node version.               */
};

struct stat64 {
    /* Members required by POSIX.1 (and reserved time members)           */
    __ino_t         st_ino;             /* File serial number.           */
    __nlink_t       st_nlink;           /* Link count.                   */
    __dev_t         st_dev;             /* Device.                       */
    __mode_t        st_mode;            /* File mode.                    */
    __uid_t         st_uid;             /* User ID of the file's owner.  */
    __gid_t         st_gid;             /* Group ID of the file's group. */
    __off_t         st_size;            /* Size of file, in bytes.       */

    /* st_blksize is provided for BSD compatibility                      */
    __blksize_t     st_blksize;         /* Optimal block size for I/O.   */
                                        /* Conventially set to 1 for TPF */

    /* Time stamps                                                       */
    struct timespec st_atimespec;       /* Time of last access.          */
    struct timespec st_mtimespec;       /* Time of last modification.    */
    struct timespec st_ctimespec;       /* Time of last status change.   */

    /* st_blkcnt is provided for BSD compatibility                       */
    __blkcnt_t      st_blocks;          /* Nr. 512-byte blocks allocated.*/

    /* TPF-specific members                                              */
    int             st_igen;            /* I-node generation.            */
    rdev_t          st_rdev;            /* Major and minor numbers.      */
    int             st_inode_version;   /* I-node version.               */
};

#if defined(_TPF_RPC) || defined(_TPF_THREADS)
#define st_atime st_atimespec.tv_sec
#define st_mtime st_mtimespec.tv_sec
#define st_ctime st_ctimespec.tv_sec
#else
#define st_atime st_atimespec.ts_sec
#define st_mtime st_mtimespec.ts_sec
#define st_ctime st_ctimespec.ts_sec
#endif


/* Tell code we have these members.  */
#define  _STATBUF_ST_BLKSIZE
#define  _STATBUF_ST_RDEV

/* Encoding of the file mode.  */
#define __S_IFMT        0x7F000000UL
#define _S_IFMT         __S_IFMT
#define S_IFMP          0X00000DFFUL

/* File types.  */
#define __S_IFDIR       0X01000000UL    /* Directory.  */
#define __S_IFREG       0X02000000UL    /* Regular file.  */
#define __S_IFLNK       0X03000000UL    /* Symbolic link.  */
#define __S_IFCHR       0X04000000UL    /* Character device.  */
#define __S_IFSOCK      0X05000000UL    /* Socket.  */
#define __S_IFIFO       0X08000000UL    /* FIFO.  */
#define _S_IFIFO        __S_IFIFO
#define __S_IFBLK       0X09000000UL    /* Block device.  */
#define __TPF_IFTMP     0X40000000UL    /* Temporary file.  */

/* POSIX.1b objects. Glibc expects these to always evaluate to zero.
   For TPF, just force them to return 0.  */
#define __S_TYPEISMQ(buf)  (0)
#define __S_TYPEISSEM(buf) (0)
#define __S_TYPEISSHM(buf) (0)

/* Protection bits.  */
#define __S_ISUID       0X00000800UL    /* Set user ID on execution.  */
#define __S_ISGID       0X00000400UL    /* Set group ID on execution.  */
#define __S_ISVTX       0X00000200UL    /* Save swapped test after user (sticky).  */
#define S_ISTXT         __S_ISVTX
#define __S_IREAD       0X00000100UL    /* Read by owner.  */
#define __S_IWRITE      0X00000080UL    /* Write by owner.  */
#define __S_IEXEC       0X00000040UL    /* Execute by owner.  */


/* Definitions of flags stored in file flags word */

/* Super-user and owner changeable flags */
#define UF_SETTABLE     0x0000ffff      /* mask of own changeable flags */
#define UF_NODUMP       0x00000001      /* do lot dump file */
#define UF_IMMUTABLE    0x00000002      /* file may not be changed */
#define UF_APPEND       0x00000004      /* writes to filel may only append */

/* Super-user changeable flags */
#define SF_SETTABLE     0xffff0000      /* mask on superuser changeable flags */
#define SF_ARCHIVED     0x00010000      /* file is archived */
#define SF_IMMUTABLE    0x00020000      /* file may not be changed */
#define SF_APPEND       0x00040000      /* writes to file may only append */

/* Shorthand abbreviations of above */
#define ST_APPEND       (UF_APPEND | SF_APPEND)
#define IMMUTABLE       (UF_IMMUTABLE | SF_IMMUTABLE)

#define S_MAJOR(x)      ((((x)>>16) & 0x0000FFFF))
#define S_MINOR(x)      (((x) & 0x0000FFFF))

